@@ -37,6 +37,7 @@ c
       implicit none
       integer kmini, nmini, k1,k2,k3,km10,nmaxi,maxmini
       integer i_trace
+      integer i_aux(4) ! just for printing when i_trace > 0
 c
 ccc   parameter (nvmax=115)
 ccc   parameter (nmax=57000)
@@ -81,7 +82,7 @@ cc
       integer krep, matz,iseed, seed, tottimes,step
       integer intercept,intadjust
       integer pnsel, replow
-      integer i,ii,iii, j,jj,jjj, jndex, k,kk,kkk, lll, m,mm, nn
+      integer i,ii,iii, j,jj,jjj, jndex, k,kk, lll, m,mm, nn
       integer jmin,jmax, jerd,jnc, jreg, kstep,kount
 c unused      integer jdefaul, jbreak
       integer minigr
@@ -256,7 +257,7 @@ cc
         if(ngroup.gt.kmini) ngroup=kmini
         nrep=int(dble(krep)/ngroup)
         minigr=mini(1)+mini(2)+mini(3)+mini(4)+mini(5)
-cccc  CALL INTPR('>>> RFLTSREG ... minigr=',-1,iseed,1)
+        if(i_trace .ge. 2) call intpr(' rftls.... minigr=',-1,minigr,1)
         call rfrdraw(subdat,n,minigr,mini,ngroup,kmini)
       else
 c          krep == 0  or   n <=  2*nmini-1  ( = 599 by default)
@@ -284,23 +285,25 @@ cc
 CDDD  CALL INTPR('>>> Start initialization ... nrep=',-1,nrep,1)
 
       do 31, j=1,nvmax
-        do 33, k=1,10
+        do k=1,10
           mstock(k,j)=1000000.D0
-          do 35, kk=1,kmini
- 35         m1stock((kk-1)*10+k,j)=1000000.D0
-          do 37 i=1,nvmax
-            do 39,kk=1,kmini
- 39           c1stock((kk-1)*10+k,(j-1)*nvmax+i)=1000000.D0
+          do kk=1,kmini
+            m1stock((kk-1)*10+k,j)=1000000.D0
+          end do
+          do i=1,nvmax
+            do kk=1,kmini
+              c1stock((kk-1)*10+k,(j-1)*nvmax+i)=1000000.D0
+            end do
             cstock(k,(j-1)*nvmax+i)=1000000.D0
- 37       continue
- 33     continue
+          end do
+        end do
         means(j)=0.D0
         bmeans(j)=0.D0
         sd(j)=0.D0
-        do 46, k=1,nvmax1
+        do k=1,nvmax1
           c(j,k)=0.D0
           h(j,k)=0.D0
- 46     continue
+        end do
  31   continue
 
       do 41, j=1,nmax
@@ -319,31 +322,35 @@ CDDD  CALL INTPR('>>> Start initialization ... nrep=',-1,nrep,1)
         slutn(j)=0.D0
  41   continue
 
-      do 43,j=1,km10
- 43     flag(j)=1
+      do j=1,km10
+        flag(j)=1
+      end do
       do 45, j=1,nvmax1
         jmiss(j)=0
         xmed(j)=0.D0
         xmad(j)=0.D0
         a(j)=0.D0
         da(j)=0.D0
-        do 48,k=1,nmaxi
- 48       dath(k,j)=0.D0
+        do k=1,nmaxi
+          dath(k,j)=0.D0
+        end do
  45   continue
 
-      do 44, j=1,maxmini
+      do j=1,maxmini
         subndex(j)=0
- 44   continue
+      end do
+      do j=1,nvm11
+        hvec(j)=0.D0
+      end do
 
-      do 47,j=1,nvm11
- 47     hvec(j)=0.D0
-
-CDDD  CALL INTPR('>>> Initialization ready',-1,0,0)
+      if(i_trace .ge. 2)
+     +    call intpr(' rftls.... initialization ready',-1,0,1)
  9000 continue
 
       if(nvad.eq.1) then
-        do 23, jj=1,n
- 23       ndist(jj)=dat(jj,1)
+        do jj=1,n
+          ndist(jj)=dat(jj,1)
+        end do
         call rfshsort(ndist,n)
         call rfmcduni(ndist,n,nhalff,slutn,bstd,am,am2,factor,
      *       n-nhalff+1)
@@ -373,13 +380,7 @@ c---- - - - - - - - - Outermost loop - - - - - - - - - - - - - - - - - - -
 c----
  5555 object=10.D25
 
-      if(i_trace .ge. 2) then
-         call intpr('Main loop - number of trials nrep: ',-1,nrep,1)
-      endif
-
-      if(.not. part .or. final) then
-         nn=n
-      endif
+      if(.not. part .or. final)             nn=n
       if(part .and. fine .and. .not. final) nn=minigr
 
       if(fine.or.(.not.part.and.final)) then
@@ -413,64 +414,71 @@ c----
             kstep=1
           endif
 
-          if (n.gt.5000) then
-            nrep=1
-          endif
+          if (n .gt. 5000) nrep=1
         else
-          nhalf=int(minigr*percen)
+          nhalf= int(minigr*percen)
         endif
       endif
 
-      do 81 i=1,nsel-1
+      if(i_trace .ge. 2) then
+         i_aux(1) = nrep
+         i_aux(2) = kstep
+         i_aux(3) = nhalf
+         call intpr('Main (number of trials nrep, kstep, nhalf):',
+     +        -1, i_aux, 3)
+      endif
+      do i=1,nsel-1
          index1(i)=i
- 81   continue
+      end do
       index1(nsel)=nsel-1
 cc
       if(.not. final) then
-        do 83 i=1,10
-          do 85 j=1,ngroup
+        do i=1,10
+          do j=1,ngroup
             mcdndex(i,1,j)=10.D25
- 85       mcdndex(i,2,j)=10.D25
- 83     continue
+            mcdndex(i,2,j)=10.D25
+          end do
+        end do
       endif
       if (fine .and. .not. final) then
-        do 91, j=1,minigr
-          do 93, k=1,nvad
- 93         dath(j,k)=dat(subdat(1,j),k)
- 91     continue
+        do j=1,minigr
+          do k=1,nvad
+            dath(j,k)=dat(subdat(1,j),k)
+          end do
+        end do
       endif
       kount=0
 
 CDDD  CALL INTPR('>>> MAIN LOOP BY GROUPS: NGROUP= ',-1,ngroup,1)
 
-      do 1111 ii=1,ngroup
-CDDD  CALL INTPR('>>> LOOPING BY GROUPS...II: ',-1,ii,1)
-
+      do 1111 ii = 1,ngroup
+         if(i_trace .ge. 3)
+     +        call intpr(' rftls.... looping by group ii=',-1,ii,1)
         if(.not.fine) kount=0
         if(part .and. .not. fine) nn=mini(ii)
-        do 101 i=1,nn
+        do i=1,nn
           index2(i)=i
- 101    continue
+        end do
 
         if(part .and. .not. fine) then
           jndex=0
-          do 103 j=1,minigr
+          do j=1,minigr
             if(subdat(2,j).eq.ii) then
               jndex=jndex+1
               subndex(jndex)=subdat(1,j)
             endif
- 103      continue
-          do 105 j=1,mini(ii)
-            do 107 k=1,nvad
-              dath(j,k)=dat(subndex(j),k)
- 107        continue
- 105      continue
-        endif
-cc
-CDDD  CALL INTPR('>>> MAIN LOOP: NREP=',-1,nrep,1)
-        do 1000 i=1,nrep
-CDDD  CALL INTPR('>>> LOOPING...I: ',-1,i,1)
+          end do
 
+          do j=1,mini(ii)
+            do k=1,nvad
+              dath(j,k)=dat(subndex(j),k)
+            end do
+          end do
+        endif
+
+        do 1000 i=1,nrep
+          if(i_trace .ge. 4)
+     +          call intpr(' rftls.... for(i = 1,nrep): i=',-1,i,1)
           pnsel=nsel
           tottimes=tottimes+1
           fckwi=0.D0
@@ -506,56 +514,55 @@ c 9550     continue
           if((.not.part.and..not.final).or.(.not.fine.and.part)) then
             if(nvar.gt.1) then
               call rfequat(c,nvmax,nvmax1,hvec,nvm11,nvar,1,nerr)
-              if(nerr.ge.0) goto 126
-              jerd=jerd+1
-              if(.not.all.and.i.gt.2) goto 132
-              goto 1000
+              if(nerr.lt.0) then
+                 jerd=jerd+1
+                 if(.not.all .and. i.gt.2) goto 132
+                 goto 1000
+              endif
             else
               if(c(1,1).ne.0.D0) c(1,1)=c(1,2)/c(1,1)
             endif
 
- 126        continue
-
-            do 136 jnc=1,nvar
- 136          a(jnc)=c(jnc,1)
+            do jnc=1,nvar
+               a(jnc)=c(jnc,1)
+            end do
           endif
 
           if (final) then
             if(mstock(i,1).ne.1000000.D0) then
-              do 125 jj=1,nvar
+              do jj=1,nvar
                 a(jj)=mstock(i,jj)
- 125          continue
+              end do
             else
               goto 1111
             endif
           endif
           if (fine.and..not.final) then
             if(m1stock((ii-1)*10+i,1).ne.1000000.D0) then
-              do 131 jj=1,nvar
+              do jj=1,nvar
                 a(jj)=m1stock((ii-1)*10+i,jj)
- 131          continue
+              end do
             else
               goto 1111
             endif
           endif
 
-c     151
-          do 152 jnc=1,nn
+          do jnc=1,nn
             residu(jnc)=0.D0
-            do 153 j=1,nvar
+            do j=1,nvar
               if(part.and..not.final) then
                 residu(jnc)=residu(jnc)+a(j)*dath(jnc,j)
               else
                 residu(jnc)=residu(jnc)+a(j)*dat(jnc,j)
               endif
- 153        continue
+            end do
             if(part.and..not.final) then
               residu(jnc)=dath(jnc,nvad)-residu(jnc)
             else
               residu(jnc)=dat(jnc,nvad)-residu(jnc)
             endif
             aw(jnc)=residu(jnc)
- 152      continue
+          end do
 
           more1=.false.
           more2=.false.
@@ -571,15 +578,18 @@ CDDD  CALL INTPR('>>> INTERCEPT ADJUSTMENT 1',-1,i,1)
               call rfmcduni(aw,nn,nhalf,slutn,bstd,am,am2,
      *             factor,nn-nhalf+1)
               a(nvar)=a(nvar)+slutn(1)
-              do 154 jnc=1,nn
- 154            residu(jnc)=residu(jnc)-slutn(1)
+              do jnc=1,nn
+                residu(jnc)=residu(jnc)-slutn(1)
+              end do
             else if(intercept.eq.1) then
               call rfshsort(aw,nn)
-              do 184 jj=1,nn
- 184            am2(jj)=abs(aw(jj))
+              do jj=1,nn
+                am2(jj)=abs(aw(jj))
+              end do
               dist2=rffindq(am2,nn,nhalf,index1)
-              do 174, jj=1,nhalf
- 174            aw2(jj)=aw(index1(jj))
+              do jj=1,nhalf
+                aw2(jj)=aw(index1(jj))
+              end do
               dist2=rffindq(aw2,nhalf,1,index2)
               jnc=index1(index2(1))
               if(jnc+nmore-nmore2+nhalf-1.gt.nn.or.jnc-nmore2.lt.1)
@@ -587,11 +597,13 @@ CDDD  CALL INTPR('>>> INTERCEPT ADJUSTMENT 1',-1,i,1)
                 call rfmcduni(aw,nn,nhalf,slutn,bstd,am,am2,
      *               factor,nn-nhalf+1)
                 a(nvar)=a(nvar)+slutn(1)
-                do 169 jnc=1,nn
- 169              residu(jnc)=residu(jnc)-slutn(1)
+                do jnc=1,nn
+                   residu(jnc)=residu(jnc)-slutn(1)
+                end do
               else
- 555            do 178 jj=0,nhalf-1+nmore
- 178              aw2(jj+1)=aw(jnc-nmore2+jj)
+ 555            do jj=0,nhalf-1+nmore
+                   aw2(jj+1)=aw(jnc-nmore2+jj)
+                end do
                 nlen=nmore+1
                 call rfmcduni(aw2,nhalf+nmore,nhalf,slutn,
      *               bstd,am,am2,factor,nlen)
@@ -622,53 +634,54 @@ CDDD  CALL INTPR('>>> INTERCEPT ADJUSTMENT 1',-1,i,1)
                   endif
                 endif
                 a(nvar)=a(nvar)+slutn(1)
-                do 170 jnc=1,nn
- 170              residu(jnc)=residu(jnc)-slutn(1)
+                do jnc=1,nn
+                   residu(jnc)=residu(jnc)-slutn(1)
+                end do
               endif
             endif
           endif
 
-          do 156 jnc=1,nn
- 156        residu(jnc)=abs(residu(jnc))
+          do jnc=1,nn
+             residu(jnc)=abs(residu(jnc))
+          end do
           dist2=rffindq(residu,nn,nhalf,index2)
 c     9555
-          do 400 step=1,kstep
+          do step=1,kstep
             tottimes=tottimes+1
-            do 155, j=1,nhalf
+            do j=1,nhalf
               temp(j)=index2(j)
- 155        continue
+            end do
             call rfishsort(temp,nhalf)
-            do 157 j=1,nhalf
+            do j=1,nhalf
               if(.not.part.or.final) then
-                do 158 mm=1,nvad
+                do mm=1,nvad
                   datt(j,mm)=dat(temp(j),mm)
- 158            continue
+                end do
               else
-                do 159 mm=1,nvad
+                do mm=1,nvad
                   datt(j,mm)=dath(temp(j),mm)
- 159            continue
+                end do
               endif
- 157        continue
+            end do
             call rflsreg(nvmax1, nvmax,nvar,n,a,datt, weights, da, h,
      *           fckw,hvec,nvm11,jmiss,nvad,nn)
 
-c           171
-            do 172 jnc=1,nn
+            do jnc=1,nn
               residu(jnc)=0.D0
-              do 173 j=1,nvar
+              do j=1,nvar
                 if(part.and..not.final) then
                   residu(jnc)=residu(jnc)+a(j)*dath(jnc,j)
                 else
                   residu(jnc)=residu(jnc)+a(j)*dat(jnc,j)
                 endif
- 173          continue
+              end do
               if(part.and..not.final) then
                 residu(jnc)=dath(jnc,nvad)-residu(jnc)
               else
                 residu(jnc)=dat(jnc,nvad)-residu(jnc)
               endif
               aw(jnc)=residu(jnc)
- 172        continue
+            end do
 
             more1=.false.
             more2=.false.
@@ -684,18 +697,18 @@ CDDD  CALL INTPR('>>> INTERCEPT ADJUSTMENT 2',-1,step,1)
                 call rfmcduni(aw,nn,nhalf,slutn,bstd,am,am2,
      *               factor,nn-nhalf+1)
                 a(nvar)=a(nvar)+slutn(1)
-                do 179 jnc=1,nn
+                do jnc=1,nn
                   residu(jnc)=residu(jnc)-slutn(1)
- 179            continue
+                end do
               else if(intercept.eq.1) then
                 call rfshsort(aw,nn)
-                do 185 jj=1,nn
+                do jj=1,nn
                   am2(jj)=abs(aw(jj))
- 185            continue
+                end do
                 dist2=rffindq(am2,nn,nhalf,index1)
-                do 180, jj=1,nhalf
+                do jj=1,nhalf
                   aw2(jj)=aw(index1(jj))
- 180            continue
+                end do
                 dist2=rffindq(aw2,nhalf,1,index2)
                 jnc=index1(index2(1))
                 if(jnc+nmore-nmore2+nhalf-1.gt.nn.or.jnc-nmore2.lt.1)
@@ -703,13 +716,15 @@ CDDD  CALL INTPR('>>> INTERCEPT ADJUSTMENT 2',-1,step,1)
                   call rfmcduni(aw,nn,nhalf,slutn,bstd,am,am2,
      *                 factor,nn-nhalf+1)
                   a(nvar)=a(nvar)+slutn(1)
-                  do 168 jnc=1,nn
+                  do jnc=1,nn
                     residu(jnc)=residu(jnc)-slutn(1)
- 168              continue
+                  end do
                 else
- 666              do 181 jj=0,nhalf-1+nmore
+c---              repeat { ....
+ 666              continue
+                  do jj=0,nhalf-1+nmore
                     aw2(jj+1)=aw(jnc-nmore2+jj)
- 181              continue
+                  end do
                   nlen=nmore+1
                   call rfmcduni(aw2,nhalf+nmore,nhalf,slutn,bstd,
      *                 am,am2,factor,nlen)
@@ -738,30 +753,34 @@ CDDD  CALL INTPR('>>> INTERCEPT ADJUSTMENT 2',-1,step,1)
                       if(jnc+nmore-nmore2+nhalf-1.le.nn) goto 666
                     endif
                   endif
+c                 } (end repeat)
+
+c                 update a[nvar]
                   a(nvar)=a(nvar)+slutn(1)
-                  do 182 jnc=1,nn
+                  do jnc=1,nn
                     residu(jnc)=residu(jnc)-slutn(1)
- 182              continue
+                  end do
                 endif
               endif
             endif
 
-            do 177 jnc=1,nn
+            do jnc=1,nn
               residu(jnc)=abs(residu(jnc))
- 177        continue
+            end do
             dist2=rffindq(residu,nn,nhalf,index2)
             fckw=0.D0
-            do 176 jnc=1,nhalf
+            do jnc=1,nhalf
               fckw=fckw+residu(jnc)**2
- 176        continue
+            end do
 
-            if(step.ge.2 .and. fckw.eq.fckw1) then
-              goto 5000
-            endif
+            if(step.ge.2 .and. fckw.eq.fckw1) exit ! break {step loop}
             fckw1=fckwi
             fckwi=fckw
-            if(((i.eq.1.and.step.eq.1.and..not.fine)
-     *           .or.fckw.lt.object).and.(final)) then
+            if(final .and. ((i.eq.1.and.step.eq.1 .and. .not.fine)
+     *           .or.fckw.lt.object)) then
+              if(i_trace .ge. 3) then
+                 call dblepr('Setting objfct= ', -1, fckw,1)
+              endif
               object=fckw
               objfct=fckw
               do jjj=1,nhalf
@@ -770,10 +789,10 @@ CDDD  CALL INTPR('>>> INTERCEPT ADJUSTMENT 2',-1,step,1)
               call rfcovcopy(a,bmeans,nvar,1)
             endif
 
- 400      continue
+          end do ! step in 1..kstep
 
-cc
- 5000     if(.not. final) then
+c 5000
+          if(.not. final) then
             if(part .and. .not. fine) then
               iii=ii
             else
@@ -788,68 +807,73 @@ cc		   best solutions need to be stored.
               lll=2
             endif
 
-            do 201, j=lll,10
+            do j = lll,10
               if (fckw .le. mcdndex(j,2,iii)) then
                 if(fckw.ne.mcdndex(j,2,iii)) then
                   if(.not.fine.and.part) goto 203
                   goto 205
                 else
-                  do 207 kkk=j,10
-                    if(fckw.eq.mcdndex(kkk,2,iii)) then
-                      do 209, jjj=1,nvar
+                  do k=j,10
+                    if(fckw.eq.mcdndex(k,2,iii)) then
+                      do jjj=1,nvar
                         if(part.and..not.fine) then
                           if(a(jjj).ne.m1stock((iii-1)*10+
-     *                         kkk,jjj)) then
+     *                         k,jjj)) then
                             goto 203
                           endif
                         else
-                          if(a(jjj).ne.mstock(kkk,jjj)) then
-                            goto 205
-                          endif
+                          if(a(jjj).ne.mstock(k,jjj)) goto 205
                         endif
- 209                  continue
+                      end do
                     endif
- 207              continue
+                  end do
                 endif
-                goto 1000
-c___            .... ----
- 203            do 221,k=10,j+1,-1
-                  do 225 kk=1,nvar
+                exit ! j-loop
+c               ----
+
+cvvv            using m1stock[,]
+ 203            do k=10,j+1,-1
+                  do kk=1,nvar
                     m1stock((iii-1)*10+k,kk)=
      *                   m1stock((iii-1)*10+k-1,kk)
- 225              continue
-
+                  end do
                   mcdndex(k,1,iii)=mcdndex(k-1,1,iii)
                   mcdndex(k,2,iii)=mcdndex(k-1,2,iii)
- 221            continue
-                do 227 kk=1,nvar
+                end do
+                do kk=1,nvar
                   m1stock((iii-1)*10+j,kk)=a(kk)
- 227            continue
+                end do
                 mcdndex(j,1,iii)=i
                 mcdndex(j,2,iii)=fckw
-                goto 1000
-c___            .... ----
- 205            do 231,k=10,j+1,-1
-                  do 235 kk=1,nvar
+                exit ! j-loop
+c               ----
+
+cvvv            using mstock[,]
+ 205            do k=10,j+1,-1
+                  do kk=1,nvar
                     mstock(k,kk)= mstock(k-1,kk)
- 235              continue
+                  end do
                   mcdndex(k,1,iii)=mcdndex(k-1,1,iii)
                   mcdndex(k,2,iii)=mcdndex(k-1,2,iii)
- 231            continue
-                do 237 kk=1,nvar
+                end do
+                do kk=1,nvar
                   mstock(j,kk)=a(kk)
- 237            continue
+                end do
                 mcdndex(j,1,iii)=i
                 mcdndex(j,2,iii)=fckw
-                goto 1000
+                exit ! j-loop
+c               ----
               endif
- 201        continue
-
+            end do ! j-loop
           endif
 
  1000   continue
+c.....           end for( i = 1..nrep )
+
 
  1111 continue
+c---- -------- end for( ii = 1..ngroup )
+
 cc
       if(part .and. .not. fine) then
         fine=.true.
@@ -865,9 +889,7 @@ cc
 C     ------ == PutRNGstate() in C
       return
       end
-ccccc end {rfltsreg}
-ccccc
-
+ccccc end {rfltsreg} ===================================================
 
       subroutine rfstatis(x,xmed,xmad,aw2,intercept,nvad,nvmax1,
      *     nmax,n,nstop,MADeps,weights,y,nvar,index2)
@@ -891,22 +913,25 @@ c     nstop=0: success;  =1 : "problem": mad ~= 0
 c       regression without intercept
         do 50 j=1,nvad
           xmed(j)=0.0
-          do 10 jnc=1,n
- 10         aw2(jnc)=abs(x(jnc,j))
+          do jnc=1,n
+            aw2(jnc)=abs(x(jnc,j))
+          end do
+
           xmad(j)=rfamdan(nmax,aw2,n,index2)*1.4826
           if(abs(xmad(j)) .le. MADeps) then
             xmad(j)=0.0
-            do 20 jnc=1,n
- 20           xmad(j)=xmad(j)+aw2(jnc)
+            do jnc=1,n
+              xmad(j)=xmad(j)+aw2(jnc)
+            end do
             xmad(j)=(xmad(j)/n)*1.2533
             if(abs(xmad(j)) .le. MADeps) then
               nstop=1
               return
             endif
           endif
-          do 40 jnc=1,n
+          do jnc=1,n
             x(jnc,j)=x(jnc,j)/xmad(j)
- 40       continue
+          end do
  50     continue
 
       else
@@ -915,18 +940,19 @@ c     	regression with intercept
         xmad(nvar)=1.D0
         do 120 j=1,nvad
           if(j.eq.nvar) goto 120
-          do 70 jnc=1,n
+          do jnc=1,n
             aw2(jnc)=x(jnc,j)
- 70       continue
+          end do
           xmed(j)=rfamdan(nmax,aw2,n,index2)
-          do 80 jnc=1,n
+          do jnc=1,n
             aw2(jnc)=abs(aw2(jnc)-xmed(j))
- 80       continue
+          end do
           xmad(j)=rfamdan(nmax,aw2,n,index2)*1.4826
           if(abs(xmad(j)) .le. MADeps) then
             xmad(j)=0.0
-            do 90 jnc=1,n
- 90           xmad(j)=xmad(j)+aw2(jnc)
+            do jnc=1,n
+              xmad(j)=xmad(j)+aw2(jnc)
+            end do
             xmad(j)=(xmad(j)/n)*1.2533
             if(dabs(xmad(j)) .le. MADeps) then
               nstop=1
@@ -934,17 +960,17 @@ c     	regression with intercept
             endif
           endif
 
-          do 110 jnc=1,n
+          do jnc=1,n
             x(jnc,j)=(x(jnc,j)-xmed(j))/xmad(j)
- 110      continue
+          end do
  120    continue
 
       endif
 
-      do 270, jnc=1,n
+      do jnc=1,n
         weights(jnc)=1.0
         y(jnc)=x(jnc,nvad)
- 270  continue
+      end do
       return
       end
 cc
@@ -983,30 +1009,30 @@ cc Var
       integer j,l, jnc,ka,kplus, mm
 cc
       kplus=k+1
-      do 10 jnc=1,k
-        do 20 j=1,kplus
+      do jnc=1,k
+        do j=1,kplus
           h(jnc,j)=0.D0
- 20     continue
- 10   continue
+        end do
+      end do
       anul=0.0
       do 30 jnc=1,nnn
         call rffcn(k,f,x,jnc,n,nvad)
         dwjnc=dble(w(jnc))
         anul=anul+w(jnc)
         dyj=dble(x(jnc,kplus))
-        do 40 ka=1,k
+        do ka=1,k
           dfka=dble(f(ka))
           h(ka,k+1)=h(ka,k+1)+dwjnc*dfka*dyj
-          do 50 l=1,ka
+          do l=1,ka
             h(ka,l)=h(ka,l)+dwjnc*dfka*dble(f(l))
- 50       continue
- 40     continue
+          end do
+        end do
  30   continue
-      do 60 j=1,k
-        do 70 jnc=1,j
+      do j=1,k
+        do jnc=1,j
           h(jnc,j)=h(j,jnc)
- 70     continue
- 60   continue
+        end do
+      end do
       call rfmatnv(h,nvmax,nvmax1,hvec,nvm11,k,1,jmiss)
       mm=k+1
       fckw = rfqlsrg(k,n,nvmax1,nvmax,f,x, w,h,mm,nvad,nnn)
@@ -1017,15 +1043,15 @@ cc
       ank=anul-k
       dfact=dble(ank)
       dfact=dfckw/dfact
-      do 90 jnc=1,k
-        do 100 j=1,k
+      do jnc=1,k
+        do j=1,k
           h(jnc,j)=h(jnc,j)*dfact
- 100    continue
- 90   continue
-      do 110 jnc=1,k
+        end do
+      end do
+      do jnc=1,k
         hda=h(jnc,jnc)
         da(jnc)=sqrt(hda)
- 110  continue
+      end do
       return
       end
 ccccc
@@ -1058,12 +1084,13 @@ cc
       n=na
       npnb=n+nb
       jnk=0
-      do 10 j=1,npnb
+      do j=1,npnb
         jnk=(j-1)*nvmax
-        do 10 nc=1,nvmax
+        do nc=1,nvmax
           jnk=jnk+1
           hvec(jnk)=an(nc,j)
- 10   continue
+        end do
+      end do
       ldel=0
       jdm=nvmax
       nma=n-1
@@ -1098,8 +1125,9 @@ cc
         deter=deter*turn
         turn=1.0D0/turn
         jncd=jdelc+nma
-        do 90 jnc=jdelc,jncd
- 90       hvec(jnc)=-hvec(jnc)*turn
+        do jnc=jdelc,jncd
+          hvec(jnc)=-hvec(jnc)*turn
+        end do
         hvec(jdla)=turn
         jncb=jhfd-jdm
         jpaal=1-jdm
@@ -1110,10 +1138,10 @@ cc
             jcl=jpaal+nma
             swap=hvec(jncb)
             jncd=jdelc-1
-            do 110 jncc=jpaal,jcl
+            do jncc=jpaal,jcl
               jncd=jncd+1
               hvec(jncc)=hvec(jncc)+swap*hvec(jncd)
- 110        continue
+            end do
             hvec(jncb)=swap*turn
           endif
  120    continue
@@ -1125,21 +1153,22 @@ cc
           jpaal=(ldel-1)*jdm+1
           jcl=jpaal+nma
           jdelc=(jhfd-1)*jdm+1-jpaal
-          do 150 jncc=jpaal,jcl
+          do jncc=jpaal,jcl
             jncd=jncc+jdelc
             swap=hvec(jncc)
             hvec(jncc)=hvec(jncd)
             hvec(jncd)=swap
- 150      continue
+          end do
         endif
  160  continue
 c---
  180  jnk=0
-      do 190 j=1,npnb
-        do 190 nc=1,nvmax
+      do j=1,npnb
+        do nc=1,nvmax
           jnk=jnk+1
           an(nc,j)=hvec(jnk)
- 190  continue
+        end do
+      end do
       return
       end
 ccccc
@@ -1257,12 +1286,13 @@ cc
      *         (dble(xmad(k)))*h(nvar,nvad)
            endif
  80     continue
-        do 90 j=1,nfac
-           do 90 k=j+1,nvar
-             hnn=2.0D0*dble(xmed(j))*dble(xmed(k))*xmp2
-             h(nvar,nvar)=h(nvar,nvar)+hnn/
-     *         (dble(xmad(j))*dble(xmad(k)))*h(j,k)
- 90     continue
+        do j=1,nfac
+          do k=j+1,nvar
+            hnn=2.0D0*dble(xmed(j))*dble(xmed(k))*xmp2
+            h(nvar,nvar)=h(nvar,nvar)+hnn/
+     *           (dble(xmad(j))*dble(xmad(k)))*h(j,k)
+          end do
+        end do
         da(nvar)=dsqrt(h(nvar,nvar))
       endif
       return
@@ -1285,56 +1315,63 @@ ccccc
       n=na
       jmat=n+nb
       jnk=0
-      do 10 j=1,jmat
-         jnk=(j-1)*nvmax
-         do 10 nc=1,nvmax
-            jnk=jnk+1
-            hvec(jnk)=am(nc,j)
- 10   continue
-
+      do j=1,jmat
+        jnk=(j-1)*nvmax
+        do nc=1,nvmax
+          jnk=jnk+1
+          hvec(jnk)=am(nc,j)
+        end do
+      end do
       nznde=n-1
       lclpl=-jdm
+
       do 120 jhfd=1,n
          turn=0.D0
          lclpl=lclpl+jdm+1
          jdel=lclpl+n-jhfd
-         do 40 jncb=lclpl,jdel
+         do jncb=lclpl,jdel
            if(dabs(hvec(jncb)) .gt. dabs(turn)) then
              turn=hvec(jncb)
              ldel=jncb
            endif
- 40      continue
+         end do
          if(dabs(turn) .le. 1D-8) then
             nerr=-1
             goto 180
          endif
-         if(ldel-lclpl) 60,80,60
- 60         deter=-deter
+
+         if(ldel .ne. lclpl) then
+            deter=-deter
             ldel=ldel-jdm
             jncb=lclpl-jdm
-            do 70 jncc=jhfd,jmat
-               ldel=ldel+jdm
-               jncb=jncb+jdm
-               swap=hvec(jncb)
-               hvec(jncb)=hvec(ldel)
- 70         hvec(ldel)=swap
- 80         deter=deter*turn
+            do jncc=jhfd,jmat
+              ldel=ldel+jdm
+              jncb=jncb+jdm
+              swap=hvec(jncb)
+              hvec(jncb)=hvec(ldel)
+              hvec(ldel)=swap
+            end do
+         end if
+         deter=deter*turn
+
          if(jhfd.eq.n) goto 120
          turn=1./turn
          jncb=lclpl+1
-         do 90 jncc=jncb,jdel
- 90         hvec(jncc)=hvec(jncc)*turn
+         do jncc=jncb,jdel
+           hvec(jncc)=hvec(jncc)*turn
+         end do
          jncd=lclpl
          jrow=jhfd+1
-         do 110 jncb=jrow,n
+         do jncb=jrow,n
             jncd=jncd+1
             jnce=lclpl
             jncf=jncd
-            do 100 jncc=jrow,jmat
-               jnce=jnce+jdm
-               jncf=jncf+jdm
- 100        hvec(jncf)=hvec(jncf)-hvec(jnce)*hvec(jncd)
- 110     continue
+            do jncc=jrow,jmat
+              jnce=jnce+jdm
+              jncf=jncf+jdm
+              hvec(jncf)=hvec(jncf)-hvec(jnce)*hvec(jncd)
+            end do
+         end do
  120  continue
 
       nerr=0
@@ -1352,10 +1389,10 @@ ccccc
             hvec(jendx)=hvec(jendx)/hvec(jendc+1)
             swap=hvec(jendx)
             jncd=jbegx-1
-            do 130 jncc=jbegc,jendc
+            do jncc=jbegc,jendc
                jncd=jncd+1
                hvec(jncd)=hvec(jncd)-hvec(jncc)*swap
- 130        continue
+            end do
  140     continue
          hvec(jbegx)=hvec(jbegx)/hvec(1)
  150  continue
@@ -1367,18 +1404,19 @@ ccccc
          jendx=jendx+jdm
          jnc=jnc+jdm
          jncd=jnc
-         do 165 jncc=jbegx,jendx
+         do jncc=jbegx,jendx
             jncd=jncd+1
             hvec(jncd)=hvec(jncc)
- 165     continue
+         end do
  160  continue
 
  180  jnk=0
-      do 190 j=1,jmat
-         do 190 nc=1,nvmax
+      do j=1,jmat
+         do nc=1,nvmax
             jnk=jnk+1
             am(nc,j)=hvec(jnk)
- 190  continue
+         end do
+      end do
       return
       end
 ccccc
